GSPComposedTreeNode subclass: #GSPCollectionTreeNode
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GSP- Inspector CollectionNodes'!
GSPCollectionTreeNode comment:
'I represent the nodes whose value has a collection.
'!


!GSPCollectionTreeNode methodsFor: 'accessing'!

expandWithTreeNodeBuilder: aTNBuilder 
	" The receiver expands creating children (nodes) that represent the elements of their value."

	self value do: 
			[:each | 
			self addChild: (aTNBuilder 
						createNodeForObject: each
						name: nil
						index: 0
						parentNode: self)].
	self expanded: true! !

!GSPCollectionTreeNode methodsFor: 'printing'!

displayString
	" The receiver returns a more complete identification that a simple printString. "

	| stream strValue |
	stream := ReadWriteStream on: ''.
	self name isNil 
		ifTrue: [stream nextPutAll: self value printString]
		ifFalse: 
			[strValue := '::' , self value class printString.
			stream nextPutAll: self name , strValue].
	^stream contents! !

!GSPCollectionTreeNode methodsFor: 'private'!

changeInstVarValueAt: anIndex withOldValue: oldValue withNewValue: newValue 
	" The receiver replaces the old value (oldValue) with the new value (newValue) in your collection (your value)."

	self value remove: oldValue ifAbsent: [self errorSignal].
	self value add: newValue! !
"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

GSPCollectionTreeNode class
	instanceVariableNames: ''!


!GSPCollectionTreeNode class methodsFor: 'resources'!

icon
	"UIMaskEditor new openOnClass: self andSelector: #collection"

	<resource: #image>
	^CachedImage on: (Image extent: 16@16 depth: 2 bitsPerPixel: 2 palette: (MappedPalette withColors: ((Array new: 3) at: 1 put: ColorValue green; at: 2 put: ColorValue white; at: 3 put: (ColorValue scaledRed: 0 scaledGreen: 4227 scaledBlue: 0); yourself)) usingBits: #[0 0 0 0 42 170 170 168 37 85 85 88 37 85 85 88 37 64 5 88 37 10 129 88 37 41 97 88 37 41 85 88 37 41 85 88 37 41 97 88 37 10 129 88 37 64 5 88 37 85 85 88 37 85 85 88 42 170 170 168 0 0 0 0])! !

GSPCollectionTreeNode subclass: #GSPKeyedCollectionTreeNode
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GSP- Inspector CollectionNodes'!
GSPKeyedCollectionTreeNode comment:
'I represent the nodes whose value has a keyed collection.
'!


!GSPKeyedCollectionTreeNode methodsFor: 'accessing'!

expandWithTreeNodeBuilder: aTNBuilder 
	"The receiver expands creating children (nodes) that represent the elements of their value."

	self value keysAndValuesDo: 
			[:k :v | 
			self addChild: (aTNBuilder 
						createNodeForObject: v
						name: 'Association: ' , k printString , ' -> '
						index: k
						parentNode: self)].
	self expanded: true! !

!GSPKeyedCollectionTreeNode methodsFor: 'private'!

changeInstVarValueAt: anIndex withOldValue: oldValue withNewValue: newValue 
	"The receiver replaces the old value (oldValue) with the new value (newValue) in your collection (your 
	value). As their value is a keyed collection, it uses the index (anIndex) to replace the values."

	self value removeKey: anIndex ifAbsent: [nil].
	self value at: anIndex put: newValue! !

GSPCollectionTreeNode subclass: #GSPSequenceableCollectionTreeNode
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GSP- Inspector CollectionNodes'!
GSPSequenceableCollectionTreeNode comment:
'I represent the nodes whose value has a sequenceable collection.'!


!GSPSequenceableCollectionTreeNode methodsFor: 'private'!

changeInstVarValueAt: anIndex withOldValue: oldValue withNewValue: newValue 
	" The receiver replaces the old value (oldValue) with the new value (newValue) in your collection (your value). As their value is a sequenceable collection, it uses the index (anIndex) to replace the value."

	self value at: anIndex put: newValue! !

!GSPSequenceableCollectionTreeNode methodsFor: 'accessing'!

expandWithTreeNodeBuilder: aTNBuilder 
	" The receiver expands creating children (nodes) that represent the elements of their value."

	1 to: self value size
		do: 
			[:i | 
			self addChild: (aTNBuilder 
						createNodeForObject: (self value at: i)
						name: nil
						index: i
						parentNode: self)].
	self expanded: true! !

GSPSequenceableCollectionTreeNode subclass: #GSPStringTreeNode
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GSP- Inspector CollectionNodes'!
GSPStringTreeNode comment:
'I represent the nodes whose value has a string.
'!


!GSPStringTreeNode methodsFor: 'printing'!

displayValue
	" The receiver returns a string that represents its value. "

	^self value! !

!GSPStringTreeNode methodsFor: 'accessing'!

acceptStringAsValue: aText with: aTNBuilder 
	" The receiver receives a new string as value in a Text, to replace its current value. It notifies to their father node that the value of the variable that represents has changed. "

	| aCopy |
	aCopy := self copy.
	aCopy value: aText string.
	self parentNode replaceNode: self withNewNode: aCopy! !
"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

GSPStringTreeNode class
	instanceVariableNames: ''!


!GSPStringTreeNode class methodsFor: 'resources'!

icon
	"UIMaskEditor new openOnClass: self andSelector: #string"

	<resource: #image>
	^CachedImage on: (Image extent: 16@16 depth: 2 bitsPerPixel: 2 palette: (MappedPalette withColors: ((Array new: 3) at: 1 put: ColorValue blue; at: 2 put: ColorValue white; at: 3 put: (ColorValue scaledRed: 0 scaledGreen: 0 scaledBlue: 4227); yourself)) usingBits: #[0 0 0 0 42 170 170 168 37 85 85 88 37 85 85 88 37 64 5 88 37 10 161 88 37 37 85 88 37 10 133 88 37 80 33 88 37 37 97 88 37 10 129 88 37 64 5 88 37 85 85 88 37 85 85 88 42 170 170 168 0 0 0 0])! !

